@@ -1,6 +1,8 @@
 module Tmuxinator
   module TmuxVersion
     SUPPORTED_TMUX_VERSIONS = [
+      3.4,
+      "3.3a",
       3.3,
       "3.2a",
       3.2,
