@@ -303,14 +303,24 @@ describe Tmuxinator::Cli do
 
   describe "#stop" do
     before do
-      ARGV.replace(["stop", "foo"])
       allow(Tmuxinator::Config).to receive_messages(validate: project)
       allow(Tmuxinator::Config).to receive_messages(version: 1.9)
       allow(Kernel).to receive(:exec)
     end
 
     context "with project name" do
-      it "stop the project" do
+      it "stops the project" do
+        ARGV.replace(["stop", "foo"])
+        expect(Kernel).to receive(:exec)
+        out, err = capture_io { cli.start }
+        expect(err).to eq ""
+        expect(out).to eq ""
+      end
+    end
+
+    context "without project name" do
+      it "stops the project using .tmuxinator.yml" do
+        ARGV.replace(["stop"])
         expect(Kernel).to receive(:exec)
         out, err = capture_io { cli.start }
         expect(err).to eq ""
@@ -321,6 +331,45 @@ describe Tmuxinator::Cli do
     include_examples :unsupported_version_message, :stop, :foo
   end
 
+  describe "#stop(with project config file)" do
+    before do
+      allow(Tmuxinator::Config).to receive(:validate).and_call_original
+      allow(Tmuxinator::Config).to receive_messages(version: 1.9)
+      allow(Kernel).to receive(:exec)
+    end
+
+    it "stops the project" do
+      ARGV.replace(["stop", "--project-config=#{project_config}"])
+      expect(Tmuxinator::Config).to receive_messages(validate: project)
+      expect(Kernel).to receive(:exec)
+      out, err = capture_io { cli.start }
+      expect(err).to eq ""
+      expect(out).to eq ""
+    end
+
+    it "does not stop the project if given a bogus project config file" do
+      ARGV.replace(["stop", "--project-config=bogus.yml"])
+      expect(Kernel).not_to receive(:exec)
+      expect { capture_io { cli.start } }.to raise_error(SystemExit)
+    end
+
+    it "does not set the project name" do
+      ARGV.replace(["stop", "--project-config=#{project_config}"])
+      expect(Tmuxinator::Config).
+        to(receive(:validate).
+           with(hash_including(name: nil)))
+      capture_io { cli.start }
+    end
+
+    it "does not set the project name even when set" do
+      ARGV.replace(["stop", "bar", "--project-config=#{project_config}"])
+      expect(Tmuxinator::Config).
+        to(receive(:validate).
+           with(hash_including(name: nil)))
+      capture_io { cli.start }
+    end
+  end
+
   describe "#local" do
     before do
       allow(Tmuxinator::Config).to receive_messages(validate: project)
@@ -501,7 +550,7 @@ describe Tmuxinator::Cli do
       end
 
       context "file exists" do
-        let(:path) { Tmuxinator::Config::LOCAL_DEFAULT }
+        let(:path) { Tmuxinator::Config::LOCAL_DEFAULTS[0] }
         before do
           expect(File).to receive(:exist?).with(path) { true }
         end
@@ -650,7 +699,7 @@ describe Tmuxinator::Cli do
       end
 
       it "does not render the project if given a bogus project config file" do
-        ARGV.replace(["start", "--project-config=bogus.yml"])
+        ARGV.replace(["debug", "--project-config=bogus.yml"])
         expect { capture_io { cli.start } }.to raise_error(SystemExit)
       end
     end
@@ -783,12 +832,23 @@ describe Tmuxinator::Cli do
 
   describe "#list" do
     before do
-      ARGV.replace(["list"])
       allow(Dir).to receive_messages(:[] => ["/path/to/project.yml"])
     end
 
-    it "lists all projects" do
-      expect { capture_io { cli.start } }.to_not raise_error
+    context "set --newline flag " do
+      ARGV.replace(["list --newline"])
+
+      it "force output to be one entry per line" do
+        expect { capture_io { cli.start } }.to_not raise_error
+      end
+    end
+
+    context "no arguments are given" do
+      ARGV.replace(["list"])
+
+      it "lists all projects " do
+        expect { capture_io { cli.start } }.to_not raise_error
+      end
     end
   end
 
